.. small_gicp documentation master file, created by
   sphinx-quickstart on Wed Jun  5 11:07:43 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to small_gicp's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   small_gicp



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
